@@ -696,6 +696,15 @@ char *yon_cut(char *source, int size, int startpos);
 
 int yon_char_check_element(char *target, char *element, char *divider);
 
+
+/// @brief Swap 2 substrings.
+/// @param source Source string
+/// @param a First substring to swap 
+/// @param b Second substring to swap
+/// @param divider String divider
+/// @return Type: char*. String with swapped substrings. The data is owned by the caller of the method.
+char *yon_char_swap_element(const char *source, const char *a, const char *b, const char *divider);
+
 /**
  * @brief Check if string begins with substring.
  * 
